@@ -1565,3 +1565,14 @@ GSList *siril_file_chooser_get_filenames(GtkFileChooser *chooser) {
 
     return filenames;
 }
+
+/* useful for debugging, checking when an image buffer changes or differs between runs */
+/*uint32_t djb33_hash(const char* s, size_t len) {
+    uint32_t h = 5381;
+    while (len--) {
+        // h = 33 * h ^ s[i];
+        h += (h << 5);
+        h ^= *s++;
+    }
+    return h;
+}*/
